.. parver documentation master file

parver documentation
========================

``parver`` is a Python package for parsing and manipulating `PEP 440`_ version
numbers.

Head over to :doc:`installation` or :doc:`usage` to get started.

.. _`PEP 440`: https://www.python.org/dev/peps/pep-0440/

.. toctree::
   :hidden:

   installation
   usage
   api
   changelog
   license
